@@ -70,7 +70,6 @@ class StemLayer(tf.keras.layers.Layer):
     def __init__(self, activation="relu"):
         super(StemLayer, self).__init__()
 
-        self.resize = Resizing(height=299, width=299)
         self.conv2d_1 = Conv2D(
             filters=32,
             kernel_size=(3, 3),
@@ -159,8 +158,7 @@ class StemLayer(tf.keras.layers.Layer):
         self.concat_3 = Concatenate(axis=-1)
 
     def call(self, stem_input):
-        resize_out = self.resize(stem_input)
-        conv1_out = self.conv2d_1(resize_out)
+        conv1_out = self.conv2d_1(stem_input)
         conv2_out = self.conv2d_2(conv1_out)
         conv3_out = self.conv2d_3(conv2_out)
         maxpool1_out = self.max_pool_1(conv3_out)
@@ -607,7 +605,7 @@ def build_graph(self, raw_shape):
 
 
 def InceptionResNetV2(classes=10):
-    input_layer = Input(shape=(128, 128, 3,))
+    input_layer = Input(shape=(299, 299, 3,))
     x = InceptionResnetNetwork(num_class=classes)(input_layer)
 
     return Model(inputs=input_layer, outputs=x)
